@@ -2,6 +2,8 @@
 Package where filters related to the learning architectural subdomain are implemented.
 """
 
+from typing import Optional
+
 from openedx_filters.exceptions import OpenEdxFilterException
 from openedx_filters.tooling import OpenEdxPublicFilter
 from openedx_filters.utils import SensitiveDataManagementMixin
@@ -591,6 +593,45 @@ class CourseHomeUrlCreationStarted(OpenEdxPublicFilter):
         return data.get("course_key"), data.get("course_home_url")
 
 
+class CourseEnrollmentAPIRenderStarted(OpenEdxPublicFilter):
+    """
+    Custom class used to create filters for enrollment data.
+    """
+
+    filter_type = "org.openedx.learning.home.enrollment.api.rendered.v1"
+
+    @classmethod
+    def run_filter(cls, course_key, serialized_enrollment):
+        """
+        Execute a filter with the specified signature.
+
+        Arguments:
+            course_key (CourseKey): The course key for which isStarted is being modify.
+            serialized_enrollment (dict): enrollment data
+        """
+        data = super().run_pipeline(course_key=course_key, serialized_enrollment=serialized_enrollment)
+        return data.get("course_key"), data.get("serialized_enrollment")
+
+
+class CourseRunAPIRenderStarted(OpenEdxPublicFilter):
+    """
+    Custom class used to create filters for course run data.
+    """
+
+    filter_type = "org.openedx.learning.home.courserun.api.rendered.started.v1"
+
+    @classmethod
+    def run_filter(cls, serialized_courserun):
+        """
+        Execute a filter with the specified signature.
+
+        Arguments:
+            serialized_courserun (dict): courserun data
+        """
+        data = super().run_pipeline(serialized_courserun=serialized_courserun)
+        return data.get("serialized_courserun")
+
+
 class InstructorDashboardRenderStarted(OpenEdxPublicFilter):
     """
     Custom class used to create instructor dashboard filters and its custom methods.
@@ -662,3 +703,39 @@ class InstructorDashboardRenderStarted(OpenEdxPublicFilter):
         """
         data = super().run_pipeline(context=context, template_name=template_name)
         return data.get("context"), data.get("template_name")
+
+
+class ORASubmissionViewRenderStarted(OpenEdxPublicFilter):
+    """
+    Custom class used to create ORA submission view filters and its custom methods.
+    """
+
+    filter_type = "org.openedx.learning.ora.submission_view.render.started.v1"
+
+    class RenderInvalidTemplate(OpenEdxFilterException):
+        """
+        Custom class used to stop the submission view render process.
+        """
+
+        def __init__(self, message: str, context: Optional[dict] = None, template_name: str = ""):
+            """
+            Override init that defines specific arguments used in the submission view render process.
+
+            Arguments:
+                message (str): error message for the exception.
+                context (dict): context used to the submission view template.
+                template_name (str): template path rendered instead.
+            """
+            super().__init__(message, context=context, template_name=template_name)
+
+    @classmethod
+    def run_filter(cls, context: dict, template_name: str):
+        """
+        Execute a filter with the signature specified.
+
+        Arguments:
+            context (dict): context dictionary for submission view template.
+            template_name (str): template name to be rendered by the student's dashboard.
+        """
+        data = super().run_pipeline(context=context, template_name=template_name, )
+        return data.get("context"), data.get("template_name")
