@@ -13,12 +13,15 @@ from openedx_filters.learning.filters import (
     CohortAssignmentRequested,
     CohortChangeRequested,
     CourseAboutRenderStarted,
+    CourseEnrollmentAPIRenderStarted,
     CourseEnrollmentQuerysetRequested,
     CourseEnrollmentStarted,
     CourseHomeUrlCreationStarted,
+    CourseRunAPIRenderStarted,
     CourseUnenrollmentStarted,
     DashboardRenderStarted,
     InstructorDashboardRenderStarted,
+    ORASubmissionViewRenderStarted,
     StudentLoginRequested,
     StudentRegistrationRequested,
     VerticalBlockChildRenderStarted,
@@ -544,6 +547,36 @@ class TestRenderingFilters(TestCase):
 
         self.assertDictContainsSubset(attributes, exception.__dict__)
 
+    def test_ora_submission_view_render_started(self):
+        """
+        Test ORASubmissionViewRenderStarted filter behavior under normal conditions.
+
+        Expected behavior:
+            - The filter must have the signature specified.
+            - The filter should return context and template_name in that order.
+        """
+        result = ORASubmissionViewRenderStarted.run_filter(self.context, self.template_name)
+
+        self.assertTupleEqual((self.context, self.template_name,), result)
+
+    @data(
+        (
+            ORASubmissionViewRenderStarted.RenderInvalidTemplate,
+            {"context": {"course": Mock()}, "template_name": "custom-template.html"},
+        ),
+    )
+    @unpack
+    def test_halt_ora_submission_view_render(self, dashboard_exception, attributes):
+        """
+        Test for the ora submission view exceptions attributes.
+
+        Expected behavior:
+            - The exception must have the attributes specified.
+        """
+        exception = dashboard_exception(message="You can't access the view", **attributes)
+
+        self.assertDictContainsSubset(attributes, exception.__dict__)
+
 
 class TestCohortFilters(TestCase):
     """
@@ -604,3 +637,31 @@ class TestFederatedContentFilters(TestCase):
         result = CourseHomeUrlCreationStarted.run_filter(course_key, course_home_url)
 
         self.assertTupleEqual((course_key, course_home_url,), result)
+
+    def test_course_enrollment_api_render_started(self):
+        """
+        Test CourseEnrollmentAPIRenderStarted filter behavior under normal conditions.
+
+        Expected behavior:
+            - The filter must have the signature specified.
+            - The filter should return course_key and is_started in that order.
+        """
+        course_key, serialized_enrollment = Mock(), Mock()
+
+        result = CourseEnrollmentAPIRenderStarted.run_filter(course_key, serialized_enrollment)
+
+        self.assertTupleEqual((course_key, serialized_enrollment,), result)
+
+    def test_course_run_api_render_started(self):
+        """
+        Test CourseRunAPIRenderStarted filter behavior under normal conditions.
+
+        Expected behavior:
+            - The filter must have the signature specified.
+            - The filter should return serialized_courserun.
+        """
+        serialized_courserun = Mock()
+
+        result = CourseRunAPIRenderStarted.run_filter(serialized_courserun)
+
+        self.assertEqual(serialized_courserun, result)
